==> hoteldruid-mod-ru_3.0.4-1.tar.gz: ru/funzioni.php <==
<?php

switch ($messaggio) {

case "<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file":  		$messaggio = "<div style=\"display: inline; color: red;\">ОШИБКА</div> при записи файла"; break;
case "Nome utente":  				$messaggio = "Имя пользователя"; break;
case "Password":  				$messaggio = "Пароль"; break;
case "Entra":  					$messaggio = "Логин"; break;
case "Sessione <div style=\"display: inline; color: red;\">scaduta</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Истекло</div> время сессии"; break;
case "Nome utente o password <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Неверное</div> имя пользователя или пароль"; break;
case "Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi":	$messaggio = "Чрезмерное число <div style=\"display: inline; color: red;\">неверных</div> логинов было использовано"; break;
case "minuti":  				$messaggio = "минуты"; break;
case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "После <div style=\"display: inline; color: red;\">неверного</div> логина вы должны подождать"; break;
case "secondi":  				$messaggio = "секунды"; break;
case "Il database deve essere aggiornato":  	$messaggio = "База данных должна быть обновлена"; break;
case "Aggiorna":  				$messaggio = "Обновление"; break;
case "Login per HotelDruid":  			$messaggio = "Login for HotelDruid"; break;
case "Mancano solo":  				$messaggio = "Only"; break;
case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining before locking the login"; break;
case "Manca solo":  				$messaggio = "Only"; break;
case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
case "orario del server":  			$messaggio = "server time"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "Mancano meno di":  			$messaggio = "Less than"; break;
case "giorni alla scadenza dell'account":  	$messaggio = "days left until the account expires"; break;
case "Numero eccesivo di sessioni <span style=\"color: red;\">errate</span> originate dal tuo indirizzo IP negli ultimi":	$messaggio = "Excessive number of <span style=\"color: red;\">incorrect</span> sessions from your IP address in the last"; break;
case "È possibile che qualcuno dalla tua stessa rete stia tentando di rubare il tuo accesso":	$messaggio = "It is possible that someone from your same network is trying to steal your access"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ru_3.0.8-1.tar.gz: ru/funzioni.php <==
<?php

switch ($messaggio) {

case "<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file":  		$messaggio = "<div style=\"display: inline; color: red;\">ОШИБКА</div> при записи файла"; break;
case "Nome utente":  				$messaggio = "Имя пользователя"; break;
case "Password":  				$messaggio = "Пароль"; break;
case "Entra":  					$messaggio = "Логин"; break;
case "Sessione <div style=\"display: inline; color: red;\">scaduta</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Истекло</div> время сессии"; break;
case "Nome utente o password <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Неверное</div> имя пользователя или пароль"; break;
case "Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi":	$messaggio = "Чрезмерное число <div style=\"display: inline; color: red;\">неверных</div> логинов было использовано"; break;
case "minuti":  				$messaggio = "минуты"; break;
case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "После <div style=\"display: inline; color: red;\">неверного</div> логина вы должны подождать"; break;
case "secondi":  				$messaggio = "секунды"; break;
case "Il database deve essere aggiornato":  	$messaggio = "База данных должна быть обновлена"; break;
case "Aggiorna":  				$messaggio = "Обновление"; break;
case "Login per HotelDruid":  			$messaggio = "Login for HotelDruid"; break;
case "Mancano solo":  				$messaggio = "Only"; break;
case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining before locking the login"; break;
case "Manca solo":  				$messaggio = "Only"; break;
case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
case "orario del server":  			$messaggio = "server time"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "Mancano meno di":  			$messaggio = "Less than"; break;
case "giorni alla scadenza dell'account":  	$messaggio = "days left until the account expires"; break;
case "Numero eccesivo di sessioni <span style=\"color: red;\">errate</span> originate dal tuo indirizzo IP negli ultimi":	$messaggio = "Excessive number of <span style=\"color: red;\">incorrect</span> sessions from your IP address in the last"; break;
case "È possibile che qualcuno dalla tua stessa rete stia tentando di rubare il tuo accesso":	$messaggio = "It is possible that someone from your same network is trying to steal your access"; break;
case "Non hai i privilegi per accedere a questa pagina":	$messaggio = "You do not have privileges to access this page"; break;
case "Accedi come utente amministratore o altro utente abilitato":	$messaggio = "Log in as an administrator user or another authorized user"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
